@@ -1,5 +1,6 @@
+# -*- coding: utf-8 -*-
 # DQSEGDB2
-# Copyright (C) 2018  Duncan Macleod
+# Copyright (C) 2018,2020  Duncan Macleod
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +18,10 @@
 """A simplified Python implementation of the DQSEGDB API.
 """
 
-__version__ = '1.0.0'
+try:
+    from ._version import version as __version__
+except ModuleNotFoundError:  # development mode
+    __version__ = 'dev'
+
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
 __credits__ = 'Ryan Fisher, Gary Hemming'
